function ModbusToOpcuaStepFlow()
{
  var SaveXml = function(that){ModbusToOpcuaStepFlow.prototype._SaveXml_(that);};
  this.SaveTcpToOpcua = function(that){ModbusToOpcuaStepFlow.prototype._SaveTcpToOpcua_(that);};
  this.SaveRtuToOpcua = function(that){ModbusToOpcuaStepFlow.prototype._SaveRtuToOpcua_(that);};
  this.SaveAsciiToOpcua = function(that){ModbusToOpcuaStepFlow.prototype._SaveAsciiToOpcua_(that);};
  this.SaveMqttToOpcua = function(that){ModbusToOpcuaStepFlow.prototype._SaveMqttToOpcua_(that);};
}

function ModbusToMqttStepFlow()
{
  var SaveXml = function(that){ModbusToMqttStepFlow.prototype._SaveXml_(that);};
  this.SaveTcpToMqtt = function(that){ModbusToMqttStepFlow.prototype._SaveTcpToMqtt_(that);};
  this.SaveRtuToMqtt = function(that){ModbusToMqttStepFlow.prototype._SaveRtuToMqtt_(that);};
  this.SaveAsciiToMqtt = function(that){ModbusToMqttStepFlow.prototype._SaveAsciiToMqtt_(that);};
}

function ModbusToMqttJsonStepFlow()
{
  var SaveXml = function(that){ModbusToMqttJsonStepFlow.prototype._SaveXml_(that);};
  this.SaveTcpToMqttJson = function(that){ModbusToMqttJsonStepFlow.prototype._SaveTcpToMqttJson_(that);};
  this.SaveRtuToMqttJson = function(that){ModbusToMqttJsonStepFlow.prototype._SaveRtuToMqttJson_(that);};
  this.SaveAsciiToMqttJson = function(that){ModbusToMqttJsonStepFlow.prototype._SaveAsciiToMqttJson_(that);};
}

function ModbusToMsSqlStepFlow()
{
  var SaveXml = function(that){ModbusToMsSqlStepFlow.prototype._SaveXml_(that);};
  this.SaveTcpToMsSql = function(that){ModbusToMsSqlStepFlow.prototype._SaveTcpToMsSql_(that);};
  this.SaveRtuToMsSql = function(that){ModbusToMsSqlStepFlow.prototype._SaveRtuToMsSql_(that);};
}

function ModbusToMysqlConnectionStepFlow()
{
  var SaveXml = function(that){ModbusToRMysqlConnectionStepFlow.prototype._SaveXml_(that);};
  this.SaveTcpToMysqlConnection = function(that){ModbusToMysqlConnectionStepFlow.prototype._SaveTcpToMysqlConnection_(that);};
  this.SaveRtuToMysqlConnection = function(that){ModbusToMysqlConnectionStepFlow.prototype._SaveRtuToMysqlConnection_(that);};
}

function ModbusToPidOperationStepFlow()
{
  var SaveXml = function(that){ModbusToPidOperationStepFlow.prototype._SaveXml_(that);};
  var SaveAsciiToPidOperation = function(that){ModbusToPidOperationStepFlow.prototype._SaveAsciiToPidOperation_(that);};
  this.SaveAllToPidOperation = function(that){ModbusToPidOperationStepFlow.prototype._SaveAllToPidOperation_(that);};
  this.SaveAllToPidOperationAndOpcua = function(that){ModbusToPidOperationStepFlow.prototype._SaveAllToPidOperationAndOpcua_(that);};
}

function ModbusToIftttConditionTriggerStepFlow()
{
  var SaveXml = function(that){ModbusToIftttConditionTriggerStepFlow.prototype._SaveXml_(that);};
  var SaveAsciiToIftttConditionTrigger = function(that){ModbusToIftttConditionTriggerStepFlow.prototype._SaveAsciiToIftttConditionTrigger_(that);};
  this.SaveAllToIftttConditionTrigger = function(that){ModbusToIftttConditionTriggerStepFlow.prototype._SaveAllToIftttConditionTrigger_(that);};
}

function StepFlowMqttToIoTCloud()
{
  var SaveXml = function(that){StepFlowMqttToIoTCloud.prototype._SaveXml_(that);};
  var SaveAsciiToIftttConditionTrigger = function(that){StepFlowMqttToIoTCloud.prototype._SaveAsciiToIftttConditionTrigger_(that);};
  this.SaveMqttToIoTCloud = function(that){StepFlowMqttToIoTCloud.prototype._SaveMqttToIoTCloud_(that);};
}