function main_StepFlowMqttToSpeakComPortSetting_click(that)
{
	var Class = new MqttToSpeakStepFlow();
	Class.SelectComPortSetting(that);
	Class = null;
}

function main_StepFlowMqttToSpeakUnlockAllModule_click(that)
{
	var Class = new MqttToSpeakStepFlow();
	Class.UnlockAllModule(that);
	Class = null;
}

function main_StepFlowMqttToSepakCertificate_click(that)
{
	var Class = new MqttToSpeakStepFlow();
	Class.SelectMqttCertificate(that);
	Class = null;
}

function main_StepFlowMqttToSpeakBrokerSetting_click(that)
{
	var Class = new MqttToSpeakStepFlow();
	Class.SelectBrokerSetting(that);
	Class = null;
}

function main_StepFlowSelectMqttToSpeakGroupConnection_click(that)
{
	var Class = new MqttToSpeakStepFlow();
	Class.SelectMqttGroupConnection(that);
	Class = null;
}

function main_TopStepMqttToIoTCloud_click(that)
{
	//var Class = new StepFlow();
	//Class.MasterTcpToMqttJson(that);
	//Class = null;
	var Class = new MqttToSpeakStepFlow();
	Class.MqttToIoTCloud(that);
	Class = null;
}













function main_StepFlowTcpToOpcua_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToOpcuaStepFlow();
		Class.SaveTcpToOpcua(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowRtuToOpcua_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToOpcuaStepFlow();
		Class.SaveRtuToOpcua(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowAsciiToOpcua_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToOpcuaStepFlow();
		Class.SaveAsciiToOpcua(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowSaveMqttToOpcua_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToOpcuaStepFlow();
		Class.SaveMqttToOpcua(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowRtuToMqtt_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttStepFlow();
		Class.SaveRtuToMqtt(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowTcpToMqtt_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttStepFlow();
		Class.SaveTcpToMqtt(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowAsciiToMqtt_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttStepFlow();
		Class.SaveAsciiToMqtt(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowRtuToMqttJson_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttJsonStepFlow();
		Class.SaveRtuToMqttJson(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowTcpToMqttJson_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttJsonStepFlow();
		Class.SaveTcpToMqttJson(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowAsciiToMqttJson_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMqttJsonStepFlow();
		Class.SaveAsciiToMqttJson(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowTcpToMsSql_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMsSqlStepFlow();
		Class.SaveTcpToMsSql(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowRtuToMsSql_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMsSqlStepFlow();
		Class.SaveRtuToMsSql(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowTcpToMysqlConnection_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMysqlConnectionStepFlow();
		Class.SaveTcpToMysqlConnection(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowRtuToMysqlConnection_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToMysqlConnectionStepFlow();
		Class.SaveRtuToMysqlConnection(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowPidOperation_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToPidOperationStepFlow();
		Class.SaveAllToPidOperation(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowPidOperationToOpcua_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToPidOperationStepFlow();
		Class.SaveAllToPidOperationAndOpcua(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowIftttConditionTrigger_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new ModbusToIftttConditionTriggerStepFlow();
		Class.SaveAllToIftttConditionTrigger(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowMqtToIoTCloudSave_click(that)
{
	$(that).closest('.Row').find(".BigLoading").show();
	var StepFlowClass = new StepFlow();
	StepFlowClass.LockAllUi(that);
	var SetInterval = setInterval(function()
	{
		StepFlowClass = null; delete StepFlowClass;
		var Class = new StepFlowMqttToIoTCloud();
		Class.SaveMqttToIoTCloud(that);
		clearInterval(SetInterval);
	},500);
}

function main_StepFlowMqtToIoTCloudRunProject_click(that)
{
	var Class = new StepFlowMqttToIoTCloud();
	Class.RunProject(that);
	Class = null;
}